// AlphaDoc.cpp
// (c) 2003 exeal

#include "StdAfx.h"
#include "AlphaDoc.h"
#include "AlphaView.h"
#include "Ambient.h"
using Alpha::CAlphaDoc;
using Alpha::CAlphaView;


// CAlphaDoc class implementation
/////////////////////////////////////////////////////////////////////////////

///	RXgN^
CAlphaDoc::CAlphaDoc(Alpha::CAlphaEditController* pController /* = 0 */)
		: CEditDoc(pController), m_pAutomation(0), m_iDocType(0) {
}

///	fXgN^
CAlphaDoc::~CAlphaDoc() {
	if(m_pAutomation != 0)
		m_pAutomation->Release();
}

///	I[g[VpC^[tFCXIuWFNgԂ
void CAlphaDoc::GetAutomation(Alpha::CAlphaApp* pApp, IDocument** ppDocument) {
	AssertValid();
	assert(ppDocument != 0);

	if(m_pAutomation == 0) {	// ܂΍쐬
		m_pAutomation = new Alpha::Ambient::CTextDocument(pApp, this);
		m_pAutomation->AddRef();
	}
	*ppDocument = m_pAutomation;
	(*ppDocument)->AddRef();
}

/* [EOF] */